diff vp3data.h @ 1239:fe46bd7c64d4 libavcodec

get those permutations straight
author tmmm
date Sun, 11 May 2003 02:51:07 +0000
parents 3fa9a3de913f
children 7f7aa6ac3723
line wrap: on
line diff
--- a/vp3data.h	Sat May 10 21:46:17 2003 +0000
+++ b/vp3data.h	Sun May 11 02:51:07 2003 +0000
@@ -60,7 +60,7 @@
 };
 
 /* table used to convert natural order <-> zigzag order */
-static const int dequant_index[64] =
+static const int dezigzag_index[64] =
 {   0,  1,  8,  16,  9,  2,  3, 10,
     17, 24, 32, 25, 18, 11,  4,  5,
     12, 19, 26, 33, 40, 48, 41, 34,
@@ -71,8 +71,8 @@
     53, 60, 61, 54, 47, 55, 62, 63
 };
 
-/* inverse of dequant index */
-static int quant_index[64];
+/* inverse of dezigzag index */
+static int zigzag_index[64];
 
 static const uint16_t dc_bias[16][32][2] = {
   {  /* DC bias table 0 */